@@ -23,15 +23,18 @@ Report browser views.
 from urllib import urlencode, unquote_plus
 from zope.browserpage.viewpagetemplatefile import ViewPageTemplateFile
 from zope.component import queryMultiAdapter
+from zope.component import adapts
 from zope.i18n import translate
 from zope.i18n.interfaces.locales import ICollator
 from zope.publisher.browser import BrowserView
 from zope.traversing.browser.absoluteurl import absoluteURL
 from zope.interface import implements
 from zope.cachedescriptors.property import Lazy
+from zope.proxy import getProxiedObject
 from z3c.form import button
 
 from schooltool.report.interfaces import IReportLinksURL
+from schooltool.report.interfaces import IReportLinkViewlet
 from schooltool.report.report import IFlourishReportLinkViewletManager
 from schooltool.report.report import getReportRegistrationUtility
 from schooltool.skin import flourish
@@ -167,7 +170,8 @@ class ReportsLinks(RefineLinksViewlet):
         for item in items:
             viewlet = item['viewlet']
             url = viewlet.link
-            if hasattr(viewlet, 'file_type'):
+            is_report_link = bool(getattr(viewlet, 'file_type', ''))
+            if is_report_link:
                 file_type = translate(viewlet.file_type,
                                       context=self.request)
                 description = translate(viewlet.description,
@@ -180,7 +184,7 @@ class ReportsLinks(RefineLinksViewlet):
                     'class': item['class'],
                     'viewlet': viewlet,
                     'content': item['content'],
-                    'is_report_link': hasattr(viewlet, 'file_type'),
+                    'is_report_link': is_report_link,
                     'link_id': viewlet.link.replace('.', '_'),
                     'form_id': viewlet.link.replace('.', '_') + '_form',
                     'title': translate(viewlet.title, context=self.request),
@@ -189,6 +193,20 @@ class ReportsLinks(RefineLinksViewlet):
         return result
 
 
+class ReportLinkViewletProxy(flourish.viewlet.ViewletProxy):
+
+    adapts(IReportLinkViewlet)
+
+    def __init__(self, *args, **kw):
+        super(ReportLinkViewletProxy, self).__init__(*args, **kw)
+        self.restoreSortingAttrs()
+
+    def restoreSortingAttrs(self):
+        unproxied = getProxiedObject(self)
+        self.before = getattr(unproxied, 'before', ())
+        self.after = getattr(unproxied, 'after', ())
+
+
 class RequestReportDownloadDialog(DialogForm):
 
     template = ViewPageTemplateFile('templates/f_request_report_download.pt')
