@@ -1,43 +1,3 @@
-/* This is the Javascript to be included when rendering the gradebook overview. */
-function setNotEdited()
-{
-    edited = false;
-}
-
-function setEdited()
-{
-    edited = true;
-}
-
-function checkChanges()
-{
-    if (!edited)
-        return;
-    saveFlag = window.confirm(warningText);
-    if (saveFlag == true)
-        {
-        button = document.getElementsByName('UPDATE_SUBMIT')[0];
-        button.click();
-        }
-    else
-        return true;
-}
-
-function onLoadHandler()
-{
-    // highlight error values
-    for (a = 0; a < numactivities; a++)
-    {
-        activity = activities[a];
-        for (s = 0; s < numstudents; s++)
-        {
-            name = activity + '_' + students[s];
-            value = document.getElementById(name).value;
-            setBackgroundColor(name, activity, value, true);
-        }
-    }
-}
-
 // Changes made for flourish
 
 function makeGradeCellVisible(element) {
@@ -219,6 +179,9 @@ function fillPopupMenu(link) {
     var data = link.data('popup-menu-data');
     var popup = link.prev();
     popup.empty();
+    if (!data) {
+        return;
+    }
     var header = $('<li class="header"></li>');
     header.text(data.header);
     popup.append(header);
@@ -315,6 +278,19 @@ function preloadFilldown(form) {
     });
 }
 
+function preloadCommentCell(form) {
+    var url = buildURL(form.attr('action'), 'comment_cell');
+    $.ajax({
+        url: url,
+        dataType: 'html',
+        type: 'get',
+        context: form,
+        success: function(data) {
+            this.before(data);
+        }
+    });
+}
+
 function hidePopup(form) {
     form.find('.popup_active').hide().removeClass('popup_active');
 }
@@ -354,6 +330,10 @@ function createWorksheetsList() {
     return ul;
 }
 
+function removeSavingWarning() {
+    window.onbeforeunload = null;
+}
+
 $(document).ready(function() {
     var form = $('#grid-form');
     form.data('base-font-size', parseInt(form.css('fontSize')));
@@ -363,6 +343,8 @@ $(document).ready(function() {
     $('.gradebook-part').find('tbody').find('tr:odd').addClass('odd');
     // fill down
     preloadFilldown(form);
+    // comment cell
+    preloadCommentCell(form);
     // popup menus
     preloadPopups(form);
     var gradebook = form.find('#gradebook');
@@ -433,6 +415,9 @@ $(document).ready(function() {
                     dataType: 'json',
                     type: 'get',
                     success: function(data) {
+                        if (data.hasOwnProperty('score')) {
+                            input.val(data.score);
+                        }
                         input.removeClass();
                         var css_class = 'valid';
                         if (!data.is_valid) {
@@ -527,6 +512,59 @@ $(document).ready(function() {
         container.dialog('close');
         return false;
     });
+    // comment-cell
+    form.on('click', '.comment-cell', function() {
+        hidePopup(form);
+        var container = $('#comment-cell-dialog-container');
+        var cell = $(this).closest('tr');
+        var student_idx = cell.parent().children().index(cell);
+        var student = $('#students-part tbody tr')[student_idx];
+        var student_title = $(student).find('li')[0].innerHTML;
+        var student_id = $(student).find('td').attr('id');
+        var activity_idx = $(this).parent().children().index(this);
+        var activity = $('#grades-part th')[activity_idx];
+        var activity_id = $(activity).attr('id');
+        var popup_link = $(activity).find('.popup_link');
+        var description = $(activity).find('.activity-description');
+        var value = $(this).attr('hidden_value');
+        var dialog_title = container.find('#comment-cell-dialog-title').attr('dialog_title')
+        container.find('#comment-cell-dialog-title').text(student_title);
+        container.find('#comment-student-id').val(student_id);
+        container.find('#comment-activity-id').val(activity_id);
+        container.find('#form-widgets-value').val(value);
+        FCKeditorAPI.Instances['form-widgets-value'].SetHTML(value)
+        container.find('span').html(popup_link.attr('title'));
+        container.find('p').html(description.html());
+        container.dialog({
+            'title': dialog_title,
+            'resizable': false,
+            'width': 306,
+            'minHeight': 105,
+            'dialogClass': 'narrow-dialog',
+            'modal': true
+        });
+        // XXX - this should have worked but doesn't
+        //FCKeditorAPI.Instances['form-widgets-value'].EditorDocument.body.focus()
+        return false;
+    });
+    $('body').on('click', '.comment-cell-cancel', function() {
+        var container = $('#comment-cell-dialog-container');
+        container.find('#form-widgets-value').val('');
+        container.dialog('close');
+        return false;
+    });
+    $('body').on('click', '.comment-cell-submit', function() {
+        var student_id = $('#comment-student-id').val();
+        var activity_id = $('#comment-activity-id').val();
+        var form = $('#grid-form');
+        form.append($('<input type="hidden"/>').attr({
+            'name': activity_id + '_' + student_id,
+            'value': FCKeditorAPI.Instances['form-widgets-value'].GetHTML()
+        }));
+        removeSavingWarning();
+        form.submit();
+        return false;
+    });
     // Zoom buttons
     var normal_width = 752;
     var wide_width = 944;
@@ -638,4 +676,14 @@ $(document).ready(function() {
         }
         e.preventDefault();
     });
+    // ignore warning dialog when clicking save button
+    form.on('click', 'input[type="submit"]', function() {
+        removeSavingWarning();
+    });
 });
+// warning dialog for unsaved changes
+window.onbeforeunload = function() {
+    if ($('#grid-form input[type="text"]').length > 0) {
+        return $('#unsaved-changes-warning').text();
+    }
+};
